#include <WiFi.h>
const char* ssid = "Your SSID";         // アクセスポイントのSSID
const char* password = "Your Password"; // アクセスポイントのパスワード
WiFiServer server(80);                  // 80：http用ポート番号
String strReq;                          // HTTPリクエスト
String ledState = "OFF";                // LEDの状態
unsigned long currentTime = millis();   // 現在の時刻
unsigned long previousTime = 0;         // 前の時間
const long timeoutTime = 2000;          // タイムアウト時間をミリ秒単位で定義

void setup() {
  Serial.begin(115200);
  pinMode(LED_BUILTIN, OUTPUT);         // Pico実装LEDを指定
  digitalWrite(LED_BUILTIN, LOW);       // LED OFF
  // SSIDとパスワードでWi-Fiネットワークに接続
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  // ローカルIPアドレスの表示
  Serial.println("");
  Serial.println("WiFi connected.");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
  // Webサーバー起動
  server.begin();
}

void loop(){
  // サーバに接続されていて、データの読み取りが可能なクライアントを取得
  WiFiClient client = server.available();
  if (client) { // 接続しているクライアントあり
    Serial.println("New Client.");
    String currentLine = "";
    String ttlCol = "	#1955A6";   // ロイヤルブルー (royal blue)
    String onCol = "#7159A6";     // バイオレット (violet)
    String offCol = "#758492";
    currentTime = millis();
    previousTime = currentTime;
    while (client.connected() && currentTime - previousTime <= timeoutTime) {
      currentTime = millis(); 
      if (client.available()) { // 読み取り可能なバイト数あり
        char c = client.read(); // 接続中のサーバから送られてきたデータを1バイト読む
        Serial.write(c);        // シリアルモニターに出力
        strReq += c;
        if (c == '\n') {        // 改行文字
          if (currentLine.length() == 0) {
            client.println("HTTP/1.1 200 OK");
            client.println("Content-type:text/html");
            client.println("Connection: close");
            client.println();
            // GPIOのON/OFFを切り替える
            if (strReq.indexOf("GET /H/ON") >= 0) {
              ledState = "ON";
              digitalWrite(LED_BUILTIN, HIGH);
            } else if (strReq.indexOf("GET /L/OFF") >= 0) {
              ledState = "OFF";
              digitalWrite(LED_BUILTIN, LOW);
            }
            // HTMLのWebページを表示
            client.println("<!DOCTYPE html><html>");
            client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
            client.println("<style>html { font-family: Helvetica; display: inline-block; margin: 0px auto; text-align: center;}");
            client.println(".buttonBlue { background-color: " + onCol + "; border: none; color: white; padding: 16px 40px; border-radius: 60%;");
            client.println("text-decoration: none; font-size: 30px; margin: 2px; cursor: pointer;}");
            client.println(".buttonOff { background-color: " + offCol + "; border: none; color: white; padding: 16px 40px; border-radius: 70%;");
            client.println("text-decoration: none; font-size: 30px; margin: 2px; cursor: pointer;}</style></head>");
            client.println("<body><h1><font color=\"" + ttlCol + "\">LED Control Server</font></h1>");
            client.println("<span style=\"text-align:center; font-weight: normal; font-size: x-large;\">");
            if (ledState=="OFF") {
              client.println("<p><font color=\"" + offCol + "\">LED is OFF</font></p>");
              client.println("<p><a href=\"/H/ON\"><button class=\"button buttonOff\">OFF</button></a></p>");
            } else {
              client.println("<p><font color=\"" + onCol + "\">LED is ON</font></p>");
              client.println("<p><a href=\"/L/OFF\"><button class=\"button buttonBlue\">ON</button></a></p>");
            } 
            client.println("</span>");
            client.println();
            client.println("<span style=\"text-align:center; font-weight: normal; font-style: italic; font-size: medium;\"><p><font color=\"#1955A6\">Let's do it with Ability</font></p></span>");
            client.println("</body></html>");
            client.println();
            break;
          } else {
              currentLine = "";
          }
        } else if (c != '\r') {
          currentLine += c;
        }
      }
    }
    strReq = "";
    client.stop();
    Serial.println("Client disconnected.");
    Serial.println("");
  }
}